package com.djhk.uav.equ.service;




import com.djhk.common.core.domain.TreeSelect;
import com.djhk.common.core.domain.entity.SysDept;
import com.djhk.common.exception.ServiceException;
import com.djhk.uav.equ.domain.EquInfoEntity;
import com.djhk.uav.equ.domain.EquTranEntity;
import com.djhk.uav.equ.domain.dto.EquInfoExportDto;
import com.djhk.uav.equ.domain.vo.EquInfoExportVo;

import java.util.List;
import java.util.Map;

/**
 * 设备台账
 *
 * @author gzm
 * @since 1.0.0 2023-06-07
 */
public interface EquInfoService {

    List<EquInfoEntity> getEquInfoList(EquInfoEntity query);

    List<EquInfoEntity> getEquInfoLists(EquInfoEntity query);

    List<EquInfoEntity> getEquInfos(EquInfoEntity query);

    public EquInfoEntity selectEquInfoById(String equId);

    int saves(EquInfoEntity vo);

    int update(EquInfoEntity vo);

    int delete(String[] equIds);

    int updateEquInfoByIds(String[] equIds);

    List<EquTranEntity> getEquTranList(EquTranEntity query);

    int saveTran(EquTranEntity vo);

    List<EquTranEntity> getTranStsByEquId(String equId);

    int reciveTranMethod(Map vo);

    List<Object> getTjTree();

    List<TreeSelect> getTjTreeForDept(SysDept dept);

    List<EquInfoEntity> selectMonitorEquList(String[] typeIds);

    EquInfoEntity selectEquInfoByEquSn(EquInfoEntity vo);

    List<EquInfoEntity> selectEquInfoExportList(EquInfoEntity equInfoEntity);


    String importData(List<EquInfoExportDto> userList, Boolean isUpdateSupport) throws ServiceException;
}
